<!--  -*- Mode: GFM; -*-                                                       -->
<!--                                                                           -->
<!--  © Copyright IBM Corporation 2016, 2017, 2018                             -->
<!--  LICENSE: MIT License (https://opensource.org/licenses/mit-license.html)  -->
<!--  AUTHOR: Jamie A. Jennings                                                -->

# Rosie Standard Library

The RPL "standard library" is bundled with Rosie and contains many pre-defined
patterns.  As part of each Rosie release, the version of the library is the
version of the Rosie release.

You can find the version using the Rosie `version` command.


## Contents

_Forthcoming_


For now, please read the RPL files that define the standard library.  They are
in the Rosie distribution in the `rpl` directory.  Understanding those patterns
is a good step towards seeing how Rosie is used, and how to write your own
patterns.


<!-- The only patterns that are truly built-in are: -->

<!-- `.` (dot) -->
<!-- `$` (dollar sign) -->
<!-- `^` (caret) -->
<!-- `~` (boundary) -->

<!-- Often, you'll want to build your patterns by starting with some of the ones in Rosie's standard library (found in the `rpl` directory where Rosie is installed). -->




